@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2014-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2014-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -27,14 +27,13 @@ inline QString loadCustom(const KContacts::Addressee &contact, const QString &ke
 }
 
 ContactGrantleeCryptoObject::ContactGrantleeCryptoObject(const KContacts::Addressee &address, QObject *parent)
-    : QObject(parent),
-      mAddress(address)
+    : QObject(parent)
+    , mAddress(address)
 {
 }
 
 ContactGrantleeCryptoObject::~ContactGrantleeCryptoObject()
 {
-
 }
 
 QString ContactGrantleeCryptoObject::signaturePreference() const
