@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2013-2017 Montel Laurent <montel@kde.org>
+   Copyright (C) 2013-2019 Montel Laurent <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -18,19 +18,18 @@
 */
 
 #include "contactgrantleeimobject.h"
-#include "akonadi/contact/improtocols.h"
+#include "contacteditor/improtocols.h"
 
 using namespace KAddressBookGrantlee;
 ContactGrantleeImObject::ContactGrantleeImObject(const QString &type, const QString &address, QObject *parent)
-    : QObject(parent),
-      mType(type),
-      mAddress(address)
+    : QObject(parent)
+    , mType(type)
+    , mAddress(address)
 {
 }
 
 ContactGrantleeImObject::~ContactGrantleeImObject()
 {
-
 }
 
 QString ContactGrantleeImObject::type() const
